# GeoIP2 and GeoLite2 Test Databases

The following test databases are provided under [this license][0]:

- `GeoIP2-City-Test.mmdb`
- `GeoIP2-Country-Test.mmdb`
- `GeoLite2-ASN-Test.mmdb`
- `GeoLite2-City-Test.mmdb`
- `GeoLite2-Country-Test.mmdb`

Updates can be found in [this repository][1].

[0]: https://github.com/maxmind/MaxMind-DB/blob/main/LICENSE-MIT
[1]: https://github.com/maxmind/MaxMind-DB/tree/main/test-data

# DB-IP Lite Test Databases

The following test databases are provided under [this license][2]:

- `dbip-city-lite-test.mmdb`
- `dbip-country-lite-test.mmdb`

They have been modified to strip them down to a minimal dataset for testing.

Updates can be found at [this download page][3] from DB-IP.

[2]: https://creativecommons.org/licenses/by/4.0/
[3]: https://db-ip.com/db/lite.php
